<?php
$lang['invalidemail'] = 'L\'adressa d\'e-mail endatada n\'è betg valaivla';
$lang['empty_query'] = 'Empty query?? %s';
$lang['no_db_driver'] = 'Betg chattà drivers da banca da datas cumpatibels';
$lang['test_check_output_buffering'] = 'Checking output buffering';
$lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
$lang['phpinfo'] = 'Mussar infurmaziuns da PHP';
$lang['mod_security'] = 'Apache Mod Security';
$lang['test_check_tempnam'] = 'Checking for tempnam Function';
$lang['test_check_db_drivers'] = 'Drivers da banca da datas';
$lang['test_check_db_drivers_failed'] = 'Betg chattà dirvers da banca da datas';
$lang['test_check_register_globals'] = 'Checking PHP register globals';
$lang['test_check_register_globals_failed'] = 'PHP register globals is active. For security reasons, this should be disabled.';
$lang['test_check_disable_functions'] = 'Checking PHP disable functions';
$lang['test_check_disable_functions_failed'] = 'Warning: this is a list of functions disabled on your server.';
$lang['install_admin_db_port'] = 'Database port';
$lang['install_admin_db_port_info'] = 'If you don\'t know, leave this blank to use default settings.';
$lang['install_admin_db_socket'] = 'Database socket';
$lang['install_admin_db_socket_info'] = 'BETG SUSTEGNÌ.';
$lang['install_admin_frontendlang'] = 'Default language for the frontend. This adjusts the locale used for various default date handling functions, etc.';
$lang['install_default_encoding'] = 'In almost all cases, default_encoding should be utf-8. If you\'d like this to be different, change this but keep in mind, however, that the languages translations are all in utf-8';
$lang['installer_done'] = '[fatg]';
$lang['installer_failed'] = '[fallà]';
$lang['create_permission'] = 'Create permission ...';
$lang['add_column_sql'] = 'Adding column to %s table ...';
$lang['update_table_sql'] = 'Update %s table ...';
$lang['installing_module'] = 'Installing %s module ...';
$lang['updating_schema_version'] = 'Actualisar versiun %s dal schema ...';
$lang['upgrade_config'] = 'Actualisar config.php';
$lang['upgrade_config_info'] = 'Actualisar config';
$lang['upgrade_failed_again'] = 'One or more upgrades have failed. Please correct the problem and click the button below to recheck.';
$lang['upgrade_cache_dirs'] = 'Cleaning cache dirs';
$lang['cannot_clean_cache_dirs'] = 'Cannot cleaning cache dirs!';
$lang['upgrade_schema'] = 'Actualisar schema';
$lang['need_upgrade_schema'] = 'CMS is in need of an upgrade.<br />You are now running schema version %s and you need to be upgraded to version %s';
$lang['schema_ok'] = 'Now the CMS database is up to date using schema version %s';
$lang['noneed_upgrade_schema'] = 'The CMS database is up to date using schema version %s';
$lang['upgrade_modules'] = 'Actualisar moduls';
$lang['noneed_upgrade_modules'] = 'The core modules are up to date';
$lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of "%s" module from %s to %s ...';
$lang['upgrade_event_module_from_to'] = 'Upgrading Events of "%s" module from %s to %s ...';
$lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a "Site Down for Maintainence" message on your site';
$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it\'s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as "Needs Upgrade"';
$lang['upgrade_complete'] = 'Process d\'acutalisaziun cumplet';
$lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
$lang['here'] = 'qua';
$lang['go_to_admin'] = 'ir en il sectur d\'administraziun';
$lang['errorfilenot'] = 'Betg chattà datoteca';
$lang['errorfilenotwritable'] = 'Na pos betg scriver en datoteca';
$lang['nofiles'] = 'Questa funtauna n\'exista betg!';
$lang['is_directory'] = 'Questa funtauna è in ordinatur!';
$lang['is_readable_false'] = 'Questa funtauna n\'è betg legibla!';
$lang['checksum_match'] = 'Summa da controlla corrispunda!';
$lang['checksum_not_match'] = 'Summa da controlla na corrispunda betg!';
$lang['not_checksum'] = 'No checksum retrieve!';
$lang['format_datetime'] = '%c ';
$lang['upload_err_ini_size'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini!';
$lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
$lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
$lang['upload_err_no_file'] = 'Chargià si nagina datoteca';
$lang['upload_err_no_tmp_dir'] = 'Betg chattà in ordinatur temporar.';
$lang['upload_err_cant_write'] = 'Betg pussibel da scriver datoteca.';
$lang['upload_err_extension'] = 'File upload stopped by extension.';
$lang['upload_err_empty'] = 'Datoteca ha grondezza nulla.';
$lang['upload_err_unknown'] = 'Unknown file upload problem.';
$lang['function_file_uploads_off'] = 'file_uploads is off in your php configuration!';
$lang['upload_file_no_readable'] = 'Uploaded file is not readable!';
$lang['upload_file_multiple'] = 'Multiple file uploads are not allowed!';
$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
$lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. You can to have problems in save templates.';
$lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
$lang['test_check_magic_quotes_runtime_failed'] = 'When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. You can to have problems.';
$lang['install_admin_checksum'] = 'Check your installation';
$lang['upgrade_admin_checksum'] = 'Check your system upgrading';
$lang['checksum'] = 'Checksum test';
$lang['checksum_file'] = 'Checksum file';
$lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
$lang['checksum_passed'] = 'All checksums match!';
$lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
$lang['test_check_open_basedir'] = 'Verifitgar per PHP Open Basedir';
$lang['test_check_open_basedir_failed'] = 'Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.';
$lang['unlimited'] = 'illimità';
$lang['test_open_basedir_session_save_path'] = 'Open basedir restrictions appear to be in effect. If you have SESSION problems and ini_set works, you can try to enable session by cookies adding: ini_set(\'session.use_only_cookies\', 1);  to top of include.php';
$lang['install_warn_db_createtables'] = 'Normalmain avess quest champ adina dad esser activà. Fai attenziun sche ti deactiveschas questa funcziun';
$lang['install_admin_tablesnotcreated'] = 'Process complete. The installation process has completed, at your request database tables were not created. However, the config file has been reset and all pre-installation tests have passed. Thank you, and here is your';
$lang['info_create_dir_and_file'] = 'The HTTP Process owner cannot create a file inside a directory that it owns. This probably means that safe mode is enabled in some way. Many functions inside CMS made simple will not operate properly without this ability. Continuing is not possible.';
$lang['test_create_dir_and_file'] = 'Checking if the httpd process can create a file inside of a directory it created.';
$lang['cms_site'] = 'Pagina da CMS';
$lang['or_greater'] = 'Ni pli grond';
$lang['sitename'] = 'Num da la pagina';
$lang['warning_safe_mode'] = '<strong><em>ATTENZIUN:</em></strong> Il PHP Safe mode è activà. Quai vegn a caschunar problems cun chargiar datotecas cun tes browser sin il server (inclusiv maletgs, themes ed pachets dad XML per moduls). I vegn recumandà fermamain da contactar tes administratur per deactivar il safe mode.';
$lang['test'] = 'Test ';
$lang['results'] = 'Resultats';
$lang['untested'] = 'Betg exequì in test. ';
$lang['owner'] = 'Possessur';
$lang['permissions'] = 'Autorisaziun';
$lang['off'] = 'Deactivà';
$lang['on'] = 'Activà';
$lang['permission_information'] = 'Infurmaziuns d\'autorisaziun';
$lang['server_os'] = 'Sistem operativ dal server';
$lang['server_api'] = 'API dal server';
$lang['server_software'] = 'Software dal server';
$lang['server_information'] = 'Infurmaziuns dal server ';
$lang['session_save_path'] = 'Session Save Path';
$lang['max_execution_time'] = 'Temp d\'exequir maximal';
$lang['gd_version'] = 'Versiun da GD ';
$lang['upload_max_filesize'] = 'Grondezza maximala per chargiar sin il server';
$lang['post_max_size'] = 'Maximum Post Size';
$lang['memory_limit'] = 'PHP Memory Limit';
$lang['server_db_type'] = 'Server Database';
$lang['server_db_version'] = 'Server Database Version';
$lang['phpversion'] = 'Versiun da PHP actuala';
$lang['safe_mode'] = 'PHP Safe Mode ';
$lang['php_information'] = 'Infurmaziuns da PHP';
$lang['cms_install_information'] = 'Infurmaziuns da l\'installaziun dal CMS';
$lang['cms_version'] = 'Versiun dal CMS';
$lang['systeminfo_copy_paste'] = 'Please copy and paste this selected text into your forum posting';
$lang['help_systeminformation'] = 'The information displayed below is collected from a variety of locations, and summarized here so that you may be able to conveniently find some of the information required when trying to diagnose a problem or request help with your CMS Made Simple installation.';
$lang['systeminfo'] = 'Infurmaziuns dal sistem';
$lang['systeminfodescription'] = 'Display various pieces of information about your system that may be useful in diagnosing problems';
$lang['error'] = 'Sbagl';
$lang['new_version_available'] = '<em>Remartga:</em> Ina nova versiun da CMS Made Simple è disponibla. Renda per plaschair attent l\'administratur da quest fatg.';
$lang['info_urlcheckversion'] = 'If this url is the word "none" no checks will be made.<br/>An empty string will result in a default URL being used.';
$lang['urlcheckversion'] = 'Tschertgar novas versiuns dal CMS cun questa URL';
$lang['read'] = 'Leger';
$lang['write'] = 'Scriver';
$lang['execute'] = 'Exequir';
$lang['group'] = 'Gruppa';
$lang['other'] = 'Auter';
$lang['global_umask'] = 'File Creation Mask (umask)';
$lang['errorcantcreatefile'] = 'Betg pussibel da crear ina datoteca (problem d\'autorisaziun?)';
$lang['add'] = 'Agiuntar';
$lang['about'] = 'Davart';
$lang['action'] = 'Action';
$lang['actionstatus'] = 'Action/Status';
$lang['active'] = 'Activ';
$lang['cantremove'] = 'Cannot Remove';
$lang['changepermissions'] = 'Midar l\'autorisaziun';
$lang['changepermissionsconfirm'] = 'USE CAUTION\\n\\nThis action will attempt to ensure that all of the files making up the module are writable by the web server.\\nAre you sure you want to continue?';
$lang['success'] = 'Success!';
$lang['advanced'] = 'Avanzà';
$lang['back'] = 'Anavos al menu';
$lang['cancel'] = 'Interrumper';
$lang['cantchmodfiles'] = 'Betg pussivel da midar l\'autorisaziun da tschertas datotecas';
$lang['cantremovefiles'] = 'Problem cun stidar datotecas (autorisaziun?)';
$lang['create'] = 'Crear';
$lang['database'] = 'Banca da datas';
$lang['databaseprefix'] = 'Prefix da la banca da datas';
$lang['databasetype'] = 'Tip da la banca da datas';
$lang['date'] = 'Data';
$lang['default'] = 'Standard';
$lang['delete'] = 'Stidar';
$lang['deleteconfirm'] = 'Es ti segir che ti vuls stidar - %s - ?';
$lang['description'] = 'Descripziun';
$lang['directoryexists'] = 'Quest ordinatur exista gia.';
$lang['down'] = 'Engiu';
$lang['edit'] = 'Editar';
$lang['email'] = 'Adressa d\'e-mail';
$lang['errordeletingfile'] = 'Betg pussibel da stidar la datoteca. Problem d\'autorisaziun?';
$lang['errordirectorynotwritable'] = 'Ti has nagina autorisaziun da scriver en quest ordinatur. Quai po esser causa las autorisaziuns ed il possesur da la datoteca. Il Safe mode pudess era avair in effect. ';
$lang['cachenotwritable'] = 'Cache folder is not writable. Clearing cache will not work. Please make the tmp/cache folder have full read/write/execute permissions (chmod 777).  You may also have to disable safe mode.';
$lang['modulesnotwritable'] = 'The modules folder is not writable, if you would like to install modules by uploading an XML file you need to make the modules folder have full read/write/execute permissions (chmod 777).  Safe mode may also be in effect.';
$lang['false'] = 'Fauss';
$lang['settrue'] = 'Set True';
$lang['filename'] = 'Num da la datoteca';
$lang['filesize'] = 'Grondezza da la datoteca';
$lang['help'] = 'Agid';
$lang['language'] = 'Lingua';
$lang['lastname'] = 'Num da famiglia';
$lang['name'] = 'Prenum';
$lang['password'] = 'Pled-clav';
$lang['passwordagain'] = 'Pled-calv (repeter)';
$lang['remove'] = 'Eliminar';
$lang['saveconfig'] = 'Arcunar Config';
$lang['true'] = 'Endretg';
$lang['setfalse'] = 'Set False';
$lang['type'] = 'Tip';
$lang['typenotvalid'] = 'Tip n\'è betg valaivel';
$lang['unknown'] = 'Betg enconuschent';
$lang['user'] = 'Utlilisader';
$lang['userdefinedtags'] = 'User Defined Tags';
$lang['usermanagement'] = 'User Management';
$lang['username'] = 'Num d\'utilisader';
$lang['usernameincorrect'] = 'Num d\'utilisader u pled-clav betg correct';
$lang['version'] = 'Versiun';
$lang['install_title'] = 'Installaziun da CMS Made Simple (pass %s)';
$lang['install_system'] = 'Sistem d\'installaziun';
$lang['install_thanks'] = 'Engraziel che ti has installà CMS Made Simple per rumantsch';
$lang['upgrade_title'] = 'CMS Made Simple Upgrade (step %s)';
$lang['upgrade_system'] = 'Actualisar il sistem';
$lang['upgrade_thanks'] = 'Thanks for upgrading CMS Made Simple to';
$lang['install_please_read'] = 'Legia per plaschair la pagina <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/de">soluziun da problems d\'installaziun</a> en la CMS Made Simple Documentation Wiki.';
$lang['install_checking'] = 'Checking permissions and PHP settings';
$lang['install_test'] = 'Test ';
$lang['install_result'] = 'Resultat';
$lang['install_required_settings'] = 'Required settings';
$lang['install_recommended_settings'] = 'Recommended settings';
$lang['install_you_have'] = 'Ti has';
$lang['install_legend'] = 'Legenda';
$lang['install_symbol'] = 'Simbol';
$lang['install_definition'] = 'Definiziun';
$lang['install_value_passed'] = 'A required test passed';
$lang['install_value_failed'] = 'A required test failed';
$lang['install_error_fragment'] = 'Info Installation Troubleshooting';
$lang['install_value_required'] = 'A setting is below a required minimum value';
$lang['install_value_recommended'] = 'A setting is above the required value, but below the recommended value<br />or... A capability that <em>may</em> be required for some optional functionality is unavailable';
$lang['install_value_exceed'] = 'A setting meets or exceeds the recommended threshhold<br />or... A capability that <em>may</em> be required for some optional functionality is available';
$lang['install_test_failed'] = 'One or more tests have failed. You can still install the system but some functions may not work correctly.<br />Please try to correct the situation and click "Try Again", or click the Continue button.';
$lang['install_test_passed'] = 'All tests passed (at least at a minimum level). Please click the Continue button.';
$lang['install_failed_again'] = 'One or more tests have failed. Please correct the problem and click the button below to recheck.';
$lang['install_try_again'] = 'Empruar anc ina giada';
$lang['install_continue'] = 'Cuntinuar';
$lang['failure'] = 'Failure';
$lang['caution'] = 'Attenziun';
$lang['install_admin_umask'] = 'Test File Creation Mask';
$lang['install_test_umask'] = 'Please click Test button for check  ..............................';
$lang['test_umask_text'] = 'umask (abbreviated from user file creation mode mask) is a function in POSIX environments which affects the default file system mode for newly created files and directories of the current process. It controls which of the file permissions will not be set for any newly created file.';
$lang['test_check_umask'] = 'Result test on file created in';
$lang['test_umask_not_given'] = 'Umask not given';
$lang['test_check_umask_failed'] = 'Test umask failed';
$lang['test_username_not_given'] = 'Inditga nagina num d\'utilisader!';
$lang['test_username_illegal'] = 'Il num d\'utilisader cuntegna segns betg lubids!';
$lang['test_not_both_passwd'] = 'Emplenescha per plaschair omadus champs da pleds-clav!';
$lang['test_passwd_not_match'] = 'Ils champs da pled-clav na corrispundan betg!';
$lang['test_email_accountinfo'] = 'Ti has tschernì da laschar trametter las infurmaziuns da conto per e-mail, dentant inditgà nagina adressa!';
$lang['test_database_prefix'] = 'Il prefix da la banca da datas cuntegna segns betg lubids';
$lang['test_no_dbms'] = 'No dbms selected!';
$lang['test_could_not_connect_db'] = 'Could not connect to the database. Verify that username and password are correct, and that the user has access to the given database.';
$lang['test_could_not_drop_table'] = 'Could not drop a table. Verify that the user has privileges to drop tables in the given database.';
$lang['test_could_not_create_table'] = 'Could not create a table. Verify that the user has privileges to create tables in the given database.';
$lang['test_check_php'] = 'Checking for PHP version %s+';
$lang['test_min_recommend'] = '(minimum %s, recumandà %s u dapli)';
$lang['test_min_recommend_plus'] = '(min %s, recumandà %s+)';
$lang['test_requires_php_version'] = 'CMS Made Simple requires a php version of 4.3 or greater (you have %s), but PHP %s or greater is recommended to ensure maximum compatibility with third party addons';
$lang['test_check_md5_func'] = 'Checking for md5 Function';
$lang['test_check_safe_mode'] = 'Checking for safe mode';
$lang['test_check_safe_mode_failed'] = 'PHP safe mode could create some problems with uploading files and other functions. It all depends on how strict your server safe mode settings are.';
$lang['test_check_tokenizer'] = 'Checking for tokenizer functions';
$lang['test_check_tokenizer_failed'] = 'Not having the tokenizer could cause pages to render as purely white. We required you have this installed.';
$lang['test_check_gd'] = 'Checking for GD library';
$lang['test_check_gd_failed'] = 'GD library are mandatory for some modules and functionality.';
$lang['test_check_write'] = 'Checking write permission on';
$lang['test_may_not_exist'] = 'This file may not exist yet. If it does not, you should create an empty file with this name. Please also ensure that this file writable by the web server process.';
$lang['could_not_retrieve_a_value'] = 'Could not retrieve a value.... passing anyways.';
$lang['displaying_the_value_originally'] = '<br />Displaying the value originally set in the config file (this may not be accurate).';
$lang['test_check_xml_func'] = 'Checking for basic XML (expat) support';
$lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
$lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
$lang['test_remote_url'] = 'Test for remote URL';
$lang['test_remote_url_failed'] = 'You will probably not be able to open a file on a remote web server.';
$lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
$lang['remote_connection_timeout'] = 'Connection Timed Out!';
$lang['search_string_find'] = 'Connection ok!';
$lang['connection_failed'] = 'Connection failed!';
$lang['remote_response_ok'] = 'Remote response: ok!';
$lang['remote_response_404'] = 'Remote response: not found!';
$lang['remote_response_error'] = 'Remote response: error!';
$lang['test_check_file_upload'] = 'Checking file uploads';
$lang['test_check_file_failed'] = 'When file uploads are disabled you will not be able to use any of the file uploading facilities included in CMS Made Simple. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.';
$lang['test_check_memory'] = 'Checking PHP memory limit';
$lang['test_check_memory_failed'] = 'You may not have enough memory to run CMSMS correctly, or with all of your desired addons. If possible, you should try to get your system admin to raise this value. Proceed with caution.';
$lang['test_check_time_limit'] = 'Checking PHP time limit in second';
$lang['test_check_time_limit_failed'] = 'Number of seconds a script is allowed to run. If this is reached, the script returns a fatal error.';
$lang['test_check_post_max'] = 'Checking max post size';
$lang['test_check_post_max_failed'] = 'You will probably not be able to submit (larger) data. Please be aware of this restriction.';
$lang['test_check_upload_max'] = 'Checking max upload file size';
$lang['test_check_upload_max_failed'] = 'You will probably not be able to upload (larger) files using the included file management functions. Please be aware of this restriction.';
$lang['test_check_writable'] = 'Checking if %s is writable';
$lang['test_check_upload_failed'] = 'The uploads folder is not writable. You can still install the system, but you will not be able to upload files via the Admin Panel.';
$lang['test_check_images_failed'] = 'The images folder is not writable. You can still install the system, but you will not be able to upload and use images via the Admin Panel.';
$lang['test_check_modules_failed'] = 'The modules folder is not writable. You can still install the system, but you will not be able to upload modules via the Admin Panel.';
$lang['test_check_file_get_contents'] = 'Checking for file_get_contents';
$lang['test_check_file_get_contents_failed'] = 'You will probably not be able to use any of functionality that uses this function';
$lang['test_check_session_save_path'] = 'Checking if session.save_path is writable';
$lang['test_empty_session_save_path'] = 'Your session.save_path is empty. PHP will use the temporary directory of your OS. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(\'session.use_only_cookies\', 1);  to top of include.php';
$lang['test_check_session_save_path_failed'] = 'Your session.save_path is "%s". Not having this as writable may make logins to the Admin Panel not work. You may want to look into making this path writable if you have trouble logging into the Admin Panel. This test may fail if safe_mode is enabled (see below).';
$lang['test_check_ini_set'] = 'Checking if ini_set works';
$lang['test_check_ini_set_failed'] = 'Although the ability to override php ini settings is not mandatory, some addon (optional) functionality uses ini_set to extend timeouts, and allow uploading of larger files, etc. You may have difficulty with some addon functionality without this capability. This test may fail if safe_mode is enabled (see below).';
$lang['install_admin_header'] = 'Infurmaziuns dal conto d\'administratur';
$lang['install_admin_info'] = 'Select the username, password and email address for your admin account. Please make sure you record this password somewhere, as there will be no other way to login to your CMS Made Simple admin system without it.';
$lang['install_admin_email'] = 'Adressa d\'e-mail';
$lang['install_admin_email_info'] = 'E-Mail Account Information';
$lang['install_admin_email_note'] = '<strong>Note:</strong> This function uses the php\'s mail function. If you don\'t receive this email, it may be an indication that your server is not properly configured and that you should contact your host administrator.';
$lang['install_admin_sitename'] = 'This is the name of your site. It will be used in various places of the default templates and can be used anywhere with the	{sitename} tag.';
$lang['install_admin_db'] = 'Database Information';
$lang['install_admin_db_info'] = '<p>Controllescha che ti has creà tia banca da datas ed che l\'utilisader ha tut las autorisaziuns sin questa banca da datas.</p>
<p>Per MySQL, utilisescha suandant:</p>
<p>Log in to mysql from a console and run the following commands:</p>
<ol>
<li>create database cms; (use whatever name you want here but make sure to remember it, you\'ll need to enter it on this page)</li>
<li>grant all privileges on cms.* to cms_user@localhost identified by \'cms_pass\';</li>
</ol>';
$lang['install_admin_follow'] = 'Cumpetescha p. pl. suandants champs';
$lang['install_admin_db_type'] = 'Tip da la banca da datas';
$lang['install_admin_no_db'] = 'No valid database drivers appear to be compiled into your PHP install. Please confirm that you have mysql, mysqli, and/or postgres7 support installed, and try again.';
$lang['install_admin_db_host'] = 'Database host address';
$lang['install_admin_db_name'] = 'Num da la banca da datas';
$lang['install_admin_db_create'] = 'Crear tabellas (Attenziun: datas existentas vegnan stidadas)';
$lang['install_admin_db_prefix'] = 'Prefix da la tabella';
$lang['install_admin_db_sample'] = 'Installar cuntegn ed templates sco exempels';
$lang['retry'] = 'Empruar anc ina giada';
$lang['install_admin_db_create_seq'] = 'Creating %s table sequence...';
$lang['install_admin_importing'] = 'Importing sample data...';
$lang['invalid_query'] = 'Invalid query: %s';
$lang['install_creating_table'] = '<p>Creating %s table... [%s]</p>';
$lang['install_creating_index'] = '<p>Creating index in %s table... [%s]</p>';
$lang['done'] = 'done';
$lang['failed'] = 'failed';
$lang['install_admin_error_schema'] = 'Error in retrieve SQL schema';
$lang['install_admin_set_account'] = 'Setting admin account information...';
$lang['install_admin_set_sitename'] = 'Setting sitename...';
$lang['install_admin_setup'] = 'Now let\'s continue to setup your configuration file, we already have most of the stuff we need. Chances are you can leave all these values alone, so when you are ready, click Continue.';
$lang['install_admin_docroot'] = 'CMS Document root (as seen from the webserver)';
$lang['install_admin_docroot_path'] = 'Path to the Document root';
$lang['install_admin_querystring'] = 'Query string (leave this alone unless you have trouble, then edit config.php by hand)';
$lang['invalid_querys'] = '<b>WARNING<b/>: Invalid queries on your DB!';
$lang['install_admin_sitedown'] = 'Error: Could not remove the tmp/cache/SITEDOWN file. Please remove manually.';
$lang['install_admin_update_hierarchy'] = 'Updating hierarchy positions...';
$lang['install_admin_set_core_event'] = 'Setting up core events...';
$lang['install_admin_install_modules'] = 'Installar moduls...';
$lang['install_admin_index_search'] = 'Index tschertga...';
$lang['install_admin_clear_cache'] = 'Clearing site cache (if any)...';
$lang['install_admin_emailing'] = 'Trametter las infurmaziuns dal conto a l\'administratur...';
$lang['install_admin_congratulations'] = 'Congratulations, you are all setup - here is your ';
$lang['could_not_connect_db'] = 'Betg pussibel da connectar cun la banca da datas. Controllescha ch\'il num d\'utilisader ed il pled-clav sajan corrects ed che quest utilisader haja access a la banca da datas. ';
$lang['cannot_write_config'] = 'Errur: betg pussibel da scriver sin %s.';
$lang['email_accountinfo_subject'] = 'Infurmaziuns per l\'administratur da CMS Made Simple';
$lang['email_accountinfo_message'] = 'Engraziel che ti has installà CMS Made Simple per rumantsch. 

Qua èn las datas per tes conto d\'utilisader:
num d\'utilisader: %s
pled-clav: %s

S\'annunzia qua per l\'administraziun da la pagina: %s';
$lang['utma'] = '156861353.3070486175908553000.1244269983.1245694155.1245699630.24';
$lang['utmz'] = '156861353.1245699630.24.24.utmcsr=blog.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/2009/06/22/announcing-cms-made-simple-16/';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1245699630';
?>